<?php

define('WHEELSBERRY_TEMPLATE_DIR', get_template_directory()); // without the trailing slash
define('WHEELSBERRY_TEMPLATE_DIR_URI', get_template_directory_uri()); // without trailing slash
define('WHEELSBERRY_THEME_VERSION', '1.2.6');

/*************************************************************************************
 *	Load Olevmedia Framework
 *************************************************************************************/

require_once (WHEELSBERRY_TEMPLATE_DIR . '/om-framework/om-framework.php');
omfw_Framework::init();
omfw_Framework::$theme_version=WHEELSBERRY_THEME_VERSION;
omfw_Framework::$primary_style_handler='wheelsberry-style';

/*************************************************************************************
 *	Translation Text Domain
 *************************************************************************************/

load_theme_textdomain('wheelsberry', WHEELSBERRY_TEMPLATE_DIR . '/languages');

/*************************************************************************************
 *	Register Menu
 *************************************************************************************/
 
if( !function_exists( 'wheelsberry_register_menu' ) ) {
	function wheelsberry_register_menu() {
	  register_nav_menu('primary-menu', esc_html__('Primary Menu', 'wheelsberry'));
	  register_nav_menu('menu-404', esc_html__('Menu for 404 Error page', 'wheelsberry'));
	}

	add_action('init', 'wheelsberry_register_menu');
}

if( !function_exists( 'wheelsberry_primary_menu_fallback' ) ) {
	function wheelsberry_primary_menu_fallback($args) {
	  $menu_safe=wp_page_menu(array(
	  	'echo' => false,
	 	));
	 	$args['menu_class'].=' primary-menu-fallback';
	 	$menu_safe=str_replace('<div class="menu"><ul>','<div class="menu"><ul class="'.esc_attr($args['menu_class']).'">',$menu_safe);
	 	$menu_safe=str_replace('page_item_has_children','menu-item-has-children',$menu_safe);
	 	$menu_safe=preg_replace('/<ul[^>]*class=[\'"]([^\'"]*)children([^\'"]*)[\'"][^>]*>/','<div class="$1sub-menu$2"><ul>',$menu_safe);
	 	$menu_safe=str_replace('</ul>','</ul></div>',$menu_safe);
	 	$menu_safe=str_replace('</ul></div></div>','</ul></div>',$menu_safe);
	 	if(isset($args['echo']) && $args['echo'] == false) {
	 		return $menu_safe;
	 	} else {
	 		echo $menu_safe;
	 	}
	}
}

if( !function_exists( 'wheelsberry_primary_mobile_menu_fallback' ) ) {
	function wheelsberry_primary_mobile_menu_fallback($args) {
	  $menu_safe=wp_page_menu(array(
	  	'echo' => false,
	 	));
	 	$args['menu_class'].=' primary-menu-fallback';
	 	$menu_safe=str_replace('<div class="menu"><ul>','<div class="menu"><ul class="'.esc_attr($args['menu_class']).'">',$menu_safe);
	 	$menu_safe=str_replace('page_item_has_children','menu-item-has-children',$menu_safe);
	 	if(isset($args['echo']) && $args['echo'] == false) {
	 		return $menu_safe;
	 	} else {
	 		echo $menu_safe;
	 	}
	}
}

/*************************************************************************************
 *	Set Max Content Width
 *************************************************************************************/
 
if ( ! isset( $content_width ) ) $content_width = 1168;

/*************************************************************************************
 *	Post Formats
 *************************************************************************************/

if( function_exists( 'add_theme_support' ) ) {
	add_theme_support( 'post-formats', array(
			'aside',
			'gallery', 
			'link', 
			'image', 
			'quote', 
			'status',			
			'video',
			'audio',
			'chat',
	)); 
}

/*************************************************************************************
 *	Post Thumbnails
 *************************************************************************************/

add_theme_support( 'post-thumbnails' );
set_post_thumbnail_size( 144, 144, true );

/*************************************************************************************
 *	Automatic Feed Links
 *************************************************************************************/

add_theme_support( 'automatic-feed-links' );

/*************************************************************************************
 *	Register Sidebars
 *************************************************************************************/

if( !function_exists('wheelsberry_widgets_init') ) {
	function wheelsberry_widgets_init() {
		
		register_sidebar(array(
			'name' => esc_html__('Main Sidebar','wheelsberry'),
			'id' => 'sidebar-1',
			'description' => esc_html__('Sidebar that appears on the right/left (depends on Theme Options)','wheelsberry'),
			'before_widget' => '<div id="%1$s" class="sidebar-widget %2$s"><div class="sidebar-widget-inner">',
			'after_widget' => '</div></div>',
			'before_title' => '<div class="sidebar-widget-title">',
			'after_title' => '</div>',
		));
	
		$footer_columns_layout=get_option('wheelsberry_footer_layout');
		if( $footer_columns_layout == '1v4-1v4-1v4-1v4')
			$footer_columns=array(
				'footer-column-1'=>esc_html__('Footer 1st Column 1/4','wheelsberry'),
				'footer-column-2'=>esc_html__('Footer 2nd Column 1/4','wheelsberry'),
				'footer-column-3'=>esc_html__('Footer 3rd Column 1/4','wheelsberry'),
				'footer-column-4'=>esc_html__('Footer 4th Column 1/4','wheelsberry'),
			);
		elseif( $footer_columns_layout == '2v4-1v4-1v4')
			$footer_columns=array(
				'footer-column-1'=>esc_html__('Footer 1st Column 2/4','wheelsberry'),
				'footer-column-2'=>esc_html__('Footer 2nd Column 1/4','wheelsberry'),
				'footer-column-3'=>esc_html__('Footer 3rd Column 1/4','wheelsberry'),
			);
		elseif( $footer_columns_layout == '1v4-1v4-2v4')
			$footer_columns=array(
				'footer-column-1'=>esc_html__('Footer 1st Column 1/4','wheelsberry'),
				'footer-column-2'=>esc_html__('Footer 2nd Column 1/4','wheelsberry'),
				'footer-column-3'=>esc_html__('Footer 3rd Column 2/4','wheelsberry'),
			);
		elseif( $footer_columns_layout == '1v3-1v3-1v3')
			$footer_columns=array(
				'footer-column-1'=>esc_html__('Footer 1st Column 1/3','wheelsberry'),
				'footer-column-2'=>esc_html__('Footer 2nd Column 1/3','wheelsberry'),
				'footer-column-3'=>esc_html__('Footer 3rd Column 1/3','wheelsberry'),
			);
		elseif( $footer_columns_layout == '2v3-1v3')
			$footer_columns=array(
				'footer-column-1'=>esc_html__('Footer 1st Column 2/3','wheelsberry'),
				'footer-column-2'=>esc_html__('Footer 2nd Column 1/3','wheelsberry'),
			);
		elseif( $footer_columns_layout == '1v3-2v3')
			$footer_columns=array(
				'footer-column-1'=>esc_html__('Footer 1st Column 1/3','wheelsberry'),
				'footer-column-2'=>esc_html__('Footer 2nd Column 2/3','wheelsberry'),
			);
		elseif( $footer_columns_layout == '1v2-1v2')
			$footer_columns=array(
				'footer-column-1'=>esc_html__('Footer 1st Column 1/2','wheelsberry'),
				'footer-column-2'=>esc_html__('Footer 2nd Column 1/2','wheelsberry'),
			);
		else
			$footer_columns=array(
				'footer-column-1'=>esc_html__('Footer','wheelsberry'),
			);
	
		foreach($footer_columns as $id=>$name) {
			register_sidebar(array(
				'name' => $name,
				'description' => esc_html__('Appears in the footer of the site','wheelsberry'),
				'id' => $id,
				'before_widget' => '<div id="%1$s" class="footer-widget %2$s"><div class="footer-widget-inner">',
				'after_widget' => '</div></div>',
				'before_title' => '<div class="footer-widget-title">',
				'after_title' => '</div>',
			));	
		}
	
	
		$sidebars=get_option("wheelsberry_extra_sidebars");
		if(is_array($sidebars)) {
			foreach($sidebars as $k=>$v) {
				register_sidebar(array(
					'name' => esc_html__('Extra:','wheelsberry').' '.$v,
					'description' => esc_html__('This is an extra sidebar - it can be displayed on specific page instead of "Main sidebar"','wheelsberry'),
					'id' => 'extra-'.$k,
					'before_widget' => '<div id="%1$s" class="sidebar-widget %2$s"><div class="sidebar-widget-inner">',
					'after_widget' => '</div></div>',
					'before_title' => '<div class="sidebar-widget-title">',
					'after_title' => '</div>',
				));	
			}
		}
	}
}

add_action( 'widgets_init', 'wheelsberry_widgets_init' );

/*************************************************************************************
 *	Widgets
 *************************************************************************************/

include_once( WHEELSBERRY_TEMPLATE_DIR . '/widgets/facebook/facebook.php' );
include_once( WHEELSBERRY_TEMPLATE_DIR . '/widgets/cf7/cf7.php' );

/*************************************************************************************
 *	Front-end JS/CSS
 *************************************************************************************/

if(!function_exists('wheelsberry_enqueue_scripts')) {
	function wheelsberry_enqueue_scripts() {

		wp_enqueue_style('wheelsberry-style', get_stylesheet_uri(), array(), WHEELSBERRY_THEME_VERSION);
		if(get_option('wheelsberry_responsive') == 'true') {
			wp_enqueue_style('wheelsberry-responsive-mobile', WHEELSBERRY_TEMPLATE_DIR_URI.'/css/responsive-mobile.css');
			if( is_rtl() ) {
				wp_enqueue_style('wheelsberry-responsive-mobile-rtl', WHEELSBERRY_TEMPLATE_DIR_URI.'/css/responsive-mobile-rtl.css');
			}
		}

		wp_enqueue_style('omFont', WHEELSBERRY_TEMPLATE_DIR_URI.'/libraries/omFont/omFont.css' , array(), WHEELSBERRY_THEME_VERSION );
		wp_register_style('font-awesome', WHEELSBERRY_TEMPLATE_DIR_URI.'/libraries/fontawesome/css/font-awesome.min.css', array(), '4.5.0');
		wp_register_style('linecons-omfi-ext', WHEELSBERRY_TEMPLATE_DIR_URI.'/libraries/linecons/style.css');
		wp_register_style('typicons', WHEELSBERRY_TEMPLATE_DIR_URI.'/libraries/typicons/typicons.css');


		if( ! in_array(get_option('wheelsberry_prettyphoto_lightbox'), array('disabled','disabled_no_action')) ) {
			wp_enqueue_style('prettyphoto', WHEELSBERRY_TEMPLATE_DIR_URI.'/libraries/prettyphoto/css/prettyPhoto.custom.css');
			wp_enqueue_script('prettyphoto', WHEELSBERRY_TEMPLATE_DIR_URI.'/libraries/prettyphoto/js/jquery.prettyPhoto.custom.min.js', array('jquery'), false, true);
		}

		wp_register_style( 'owl-carousel', WHEELSBERRY_TEMPLATE_DIR_URI . '/libraries/owl.carousel/assets/owl.carousel.css' , array(), WHEELSBERRY_THEME_VERSION );
		wp_register_script( 'owl-carousel', WHEELSBERRY_TEMPLATE_DIR_URI . '/libraries/owl.carousel/owl.carousel.min.js' , array('jquery'), WHEELSBERRY_THEME_VERSION, true );
		
		wp_register_style('select2', WHEELSBERRY_TEMPLATE_DIR_URI.'/libraries/select2/css/select2.min.css', array(), WHEELSBERRY_THEME_VERSION);
		wp_register_script('select2', WHEELSBERRY_TEMPLATE_DIR_URI.'/libraries/select2/js/select2.min.js', array('jquery'), WHEELSBERRY_THEME_VERSION, true);
		
		$google_maps_api_key=get_option('wheelsberry_google_maps_api_key');
		if($google_maps_api_key != '') {
			wp_register_script('om-google-maps-api', 'https://maps.googleapis.com/maps/api/js?key='.esc_attr($google_maps_api_key).'&callback=om_google_maps_api_loaded', array(), false, true);
		}

		wp_enqueue_script('one-page-nav-om', WHEELSBERRY_TEMPLATE_DIR_URI.'/js/jquery.nav.om.js', array('jquery'), false, true);
		wp_enqueue_script('superfish', WHEELSBERRY_TEMPLATE_DIR_URI.'/js/jquery.superfish.min.js', array('jquery'), false, true);
		wp_register_script('omSlider', WHEELSBERRY_TEMPLATE_DIR_URI.'/js/jquery.omslider.min.js', array('jquery'), false, true);
		wp_register_script('isotope-om', WHEELSBERRY_TEMPLATE_DIR_URI.'/js/isotope.pkgd.om.min.js', array('jquery'), false, true);
		wp_enqueue_script('wheelsberry-custom', WHEELSBERRY_TEMPLATE_DIR_URI.'/js/custom.js', array('jquery'), WHEELSBERRY_THEME_VERSION, true);
		
		if(get_option('wheelsberry_sidebar_sliding') == 'true') {
			wp_enqueue_script('om-sticky-sidebar', WHEELSBERRY_TEMPLATE_DIR_URI.'/js/jquery.om.sticky.sidebar.js', array('jquery'), false, true);
		}

		if ( is_singular() ) wp_enqueue_script( 'comment-reply' );

    global $wp_locale;
    $aryArgs = array(
      'monthNames'        => array_values( $wp_locale->month ),
      'monthNamesShort'   => array_values( $wp_locale->month_abbrev ),
      'dayNames'          => array_values( $wp_locale->weekday ),
      'dayNamesShort'     => array_values( $wp_locale->weekday_abbrev ),
      'dayNamesMin'       => array_values( $wp_locale->weekday_initial ),
      'firstDay'          => get_option( 'start_of_week' ),
      'isRTL'             => $wp_locale->is_rtl(),
    );
    wp_localize_script( 'jquery-ui-datepicker', 'objectL10n', $aryArgs );

    $ajaxurl = admin_url( 'admin-ajax.php' );
	if(defined('ICL_SITEPRESS_VERSION')) {
		$wpml_lang = apply_filters( 'wpml_current_language', null );
		if ( $wpml_lang ) {
			$ajaxurl = add_query_arg( 'lang', $wpml_lang, $ajaxurl );
		}
	}
	wp_localize_script( 'wheelsberry-custom', 'wheelsberryAjax', array( 'ajaxurl' => $ajaxurl ) );
  }

	add_action('wp_enqueue_scripts', 'wheelsberry_enqueue_scripts');
}

if(!function_exists('wheelsberry_async_scripts')) {
	function wheelsberry_async_scripts($tag,$handle,$src) {
		if($handle == 'om-google-maps-api') {
			$tag=str_replace('<script','<script async',$tag);
		}
		return $tag;
	}
	add_filter('script_loader_tag','wheelsberry_async_scripts',10,3);
}

// theme custom css block
if(!function_exists('wheelsberry_custom_css_block')) {
	function wheelsberry_custom_css_block() {
		
		$custom_css=get_option('wheelsberry_code_custom_css');
		if($custom_css != '') {
			wp_add_inline_style('wheelsberry-style', omfw_Framework::esc_css($custom_css));
		}
	
  }
	add_action('wp_enqueue_scripts', 'wheelsberry_custom_css_block', 11);
}

function wheelsberry_vc_prettyphoto($url, $path, $plugin) {
	if('assets/lib/prettyphoto/css/prettyPhoto.min.css' == $path && strpos($plugin, 'js_composer') !== false) {
		$url=WHEELSBERRY_TEMPLATE_DIR_URI.'/libraries/prettyphoto/css/prettyPhoto.custom.css';
	} elseif('assets/lib/prettyphoto/js/jquery.prettyPhoto.min.js' == $path && strpos($plugin, 'js_composer') !== false) {
		$url=WHEELSBERRY_TEMPLATE_DIR_URI.'/libraries/prettyphoto/js/jquery.prettyPhoto.custom.min.js';
	}
	return $url;
}
add_filter('plugins_url','wheelsberry_vc_prettyphoto',10,3);

/*************************************************************************************
 *	Extensions
 *************************************************************************************/

require_once ( WHEELSBERRY_TEMPLATE_DIR . '/libraries/aq_resizer/aq_resizer.php');
require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/misc.php' );
require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/styling.php' );
require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/social-icons.php' );
require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/templates.php' );
require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/breadcrumbs.php' );
require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/menu-hash.php' );
require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/comments.php' );
require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/facebook-comments.php' );
require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/images.php' );
require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/speakers.php' );
require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/gallery-interface.php' );
require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/live-customizer.php' );
require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/icons.php' );
$wpb_dir='/wpb';
if ( defined( 'WPB_VC_VERSION' ) && version_compare(WPB_VC_VERSION, '5.0', '<') ) {
	$wpb_dir = '/wpb-4.12';
}
require_once ( WHEELSBERRY_TEMPLATE_DIR . $wpb_dir.'/wpb.php' );
require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/custom-javascript.php' );
require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/car-reservation.php' );
	
if(is_admin()) {
	require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/plugins.php' );
	require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/demo-import.php' );
	require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/common-meta.php' );
	require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/metaboxes-theme.php' );
	require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/page-meta.php' );
	require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/post-meta.php' );
	require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/sidebars-manager.php' );
	require_once ( WHEELSBERRY_TEMPLATE_DIR . '/functions/theme-options.php' );
}

/*************************************************************************************
 *	Embed wrap
 *************************************************************************************/

function wheelsberry_embed_oembed_html($html) {
	
	if(strpos($html, '<blockquote class="twitter-tweet"') === false)
		return '<div class="responsive-embed">'.$html.'</div>';
	else
		return $html;
	
}
add_filter('embed_oembed_html', 'wheelsberry_embed_oembed_html');

/*************************************************************************************
 *	Title
 *************************************************************************************/

function wheelsberry_title_tag() {
   add_theme_support( 'title-tag' );
}
add_action( 'after_setup_theme', 'wheelsberry_title_tag' );

/*************************************************************************************
 *	Content
 *************************************************************************************/

function wheelsberry_the_content_container($content) {
	if(!preg_match('/class=["\'][^"\']*vc_row[^"\']+om-container[^"\']*["\']/', $content)) {
		$content='<div class="om-container content-pane"><div class="om-container__inner">'."\n".$content."\n".'</div></div>';
	}
	return $content;
}
//add_filter( 'the_content', 'wheelsberry_the_content_container', 999999);

/*************************************************************************************
 *	Back to top button
 *************************************************************************************/
 
if(!function_exists('wheelsberry_back_to_top')) {
	function wheelsberry_back_to_top() {
		echo '<div class="om-back-to-top"></div>';
  }
	if(get_option('wheelsberry_display_back_to_top') == 'true')
		add_action('wp_footer', 'wheelsberry_back_to_top');
}

/*************************************************************************************
 *	Contact Form 7 Styling
 *************************************************************************************/
 
if(!function_exists('wheelsberry_contact_form_7_ajax')) {
	function wheelsberry_contact_form_7_ajax($url) {
		$url=omfw_Framework::svg_url_data('<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 48 48" width="28" height="28">
<circle class="path" cx="24" cy="24" r="20" fill="none" stroke="'.get_option('wheelsberry_side_text_color').'" stroke-width="4">
  <animate attributeName="stroke-dasharray" attributeType="XML" from="1,200" to="89,200" values="1,200; 89,200; 89,200" keyTimes="0; 0.5; 1" dur="1.5s" repeatCount="indefinite" />
  <animate attributeName="stroke-dashoffset" attributeType="XML" from="0" to="-124" values="0; -35; -124" keyTimes="0; 0.5; 1" dur="1.5s" repeatCount="indefinite" />
  <animateTransform attributeName="transform" attributeType="XML" type="rotate" from="0 24 24" to="360 24 24" dur="3s" repeatCount="indefinite"/>
</circle>
</svg>');
		return $url;
  }
	add_filter('wpcf7_ajax_loader', 'wheelsberry_contact_form_7_ajax');
}

if(!function_exists('wheelsberry_contact_form_7_def_form')) {
	function wheelsberry_contact_form_7_def_form($template, $prop) {
		if('form' == $prop) {
		$template =
			"<p class=\"one-third\">\n<label>" . esc_html__( 'First Name', 'wheelsberry' ). " *</label>\n".
			"[text* first-name placeholder \"".esc_html__( 'Enter your first name', 'wheelsberry' )."\"]\n</p>" . "\n\n".
			"<p class=\"one-third\">\n<label>" . esc_html__( 'Last Name', 'wheelsberry' ). " *</label>\n".
			"[text* last-name placeholder \"".esc_html__( 'Enter your last name', 'wheelsberry' )."\"]\n</p>" . "\n\n".
			"<p class=\"one-third\">\n<label>" . esc_html__( 'Age', 'wheelsberry' ). " *</label>\n".
			"[number age min:1 max:150 \"21\"]\n</p>" . "\n\n".
			"<p class=\"one-half\">\n<label>" . esc_html__( 'Phone Number', 'wheelsberry' ). " *</label>\n".
			"[text* phone placeholder \"".esc_html__( 'Enter your phone number', 'wheelsberry' )."\"]\n</p>" . "\n\n".
			"<p class=\"one-half\">\n<label>" . esc_html__( 'Email', 'wheelsberry' ). " *</label>\n".
			"[email* email placeholder \"".esc_html__( 'Enter your email address', 'wheelsberry' )."\"]\n</p>" . "\n\n".
			"<p>\n<label>" . esc_html__( 'Address', 'wheelsberry' ). " *</label>\n".
			"[text* address placeholder \"".esc_html__( 'Enter your address', 'wheelsberry' )."\"]\n</p>" . "\n\n".
			"<p class=\"one-third\">\n<label>" . esc_html__( 'City', 'wheelsberry' ). " *</label>\n".
			"[text* city placeholder \"".esc_html__( 'Enter your city', 'wheelsberry' )."\"]\n</p>" . "\n\n".
			"<p class=\"one-third\">\n<label>" . esc_html__( 'Country', 'wheelsberry' ). " *</label>\n".
			"[text* country placeholder \"".esc_html__( 'Enter your country', 'wheelsberry' )."\"]\n</p>" . "\n\n".
			"<p class=\"one-third\">\n<label>" . esc_html__( 'Zip Code', 'wheelsberry' ). " *</label>\n".
			"[text* zip-code placeholder \"".esc_html__( 'Enter your zip code', 'wheelsberry' )."\"]\n</p>" . "\n\n".
			'<p class="submit">[submit "' . esc_html__( 'Book Now', 'wheelsberry' ) . '"]</p>';
		}

		if('mail' == $prop) {
			$template['body'] =
				esc_html__( 'New Car Booking', 'wheelsberry' ).":\n".
				"\n".
				esc_html__( 'Car', 'wheelsberry' ).": [car-model]\n".
				esc_html__( 'Date', 'wheelsberry' ).": [pick-up-date] [pick-up-time] - [drop-off-date] [drop-off-time]\n".
				esc_html__( 'Pick-Up Location', 'wheelsberry' ).": [pick-up-location]\n".
				esc_html__( 'Drop-Off Location', 'wheelsberry' ).": [drop-off-location]\n".
				esc_html__( 'Extra Options', 'wheelsberry' ).": [extra-options]\n".
				"\n".
				"\n".
				esc_html__( 'Personal Information', 'wheelsberry' ).":\n".
				"\n".
				esc_html__( 'Name', 'wheelsberry' ).": [first-name] [last-name]\n".
				esc_html__( 'Age', 'wheelsberry' ).": [age]\n".
				esc_html__( 'Email', 'wheelsberry' ).": <[email]>\n".
				esc_html__( 'Phone number', 'wheelsberry' ).": [phone]\n".
				esc_html__( 'Address', 'wheelsberry' ).": [address]\n".
				esc_html__( 'City', 'wheelsberry' ).": [city]\n".
				esc_html__( 'Country', 'wheelsberry' ).": [country]\n".
				esc_html__( 'ZIP Code', 'wheelsberry' ).": [zip-code]".
				esc_html__( 'Total', 'wheelsberry' ).": [total-days]\n";
				
			$template['subject'] = esc_html__( 'New Car Booking', 'wheelsberry' );
			$template['sender'] = esc_html__( 'Booking Form', 'wheelsberry' );
			if(class_exists('WPCF7_ContactFormTemplate')) {
				$template['sender'] .= ' <'.WPCF7_ContactFormTemplate::from_email().'>';
			}
			$template['additional_headers'] = 'Reply-To: [email]';
		}
				
		return $template;
  }
	add_filter('wpcf7_default_template', 'wheelsberry_contact_form_7_def_form', 10, 2);
}

if(!function_exists('wheelsberry_wpcf7_form_elements')) {
	function wheelsberry_wpcf7_form_elements($html) {
		$html=preg_replace('/(<label.*?)\*(.*?<\/label>)/','$1<span class="wpcf7-form-required-label">*</span>$2',$html);
		return '<div class="wpcf7-form-elements">'.$html.'</div>';
	}
	add_filter('wpcf7_form_elements', 'wheelsberry_wpcf7_form_elements');
}

if(!function_exists('wheelsberry_wpcf7_collect_mail_tags')) {
	function wheelsberry_wpcf7_collect_mail_tags($tags) {
		$tags=array_merge($tags,array(
			'car-model',
			'pick-up-date',
			'pick-up-time',
			'drop-off-date',
			'drop-off-time',
			'pick-up-location',
			'drop-off-location',
			'extra-options',
			'total-days',
		));
		return $tags;
	}
	add_filter('wpcf7_collect_mail_tags', 'wheelsberry_wpcf7_collect_mail_tags');
}


add_action('wpcf7_posted_data', 'get_total_days',10, 1 );
function get_total_days($array)	
{
	$pick_up_date = strtotime($array['pick-up-date'] .' '. $array['pick-up-time']);
	$drop_off_date = strtotime($array['drop-off-date'] .' '. $array['drop-off-time']);	
	
	$datediff = $drop_off_date - $pick_up_date;	
  $array["total-days"] = (string)round($datediff / (60 * 60 * 24)) * 35;
	
  return $array;
}

