<?php

function wheelsberry_widget_cf7_init() {
	register_widget( 'wheelsberry_widget_cf7' );
}
if(defined('WPCF7_VERSION')) {
	add_action( 'widgets_init', 'wheelsberry_widget_cf7_init' );
}

/* Widget Class */

class wheelsberry_widget_cf7 extends WP_Widget {

	private $instance_defaults;
	
	function __construct() {
	
		parent::__construct(
			'wheelsberry_widget_cf7',
			'Wheelsberry: '.esc_html__('Contact Form 7','wheelsberry'),
			array(
				'classname' => 'wheelsberry_widget_cf7',
				'description' => esc_html__('Widget to insert contact form', 'wheelsberry')
			)
		);
		
		$this->instance_defaults = array(
			'form_id' => '',
			'max_width' => '',
		);
		
	}

	/* Front-end display of widget. */
		
	function widget( $args, $instance ) {
		extract( $args );
		
		$instance = wp_parse_args( (array) $instance, $this->instance_defaults );
	
		echo wp_kses($before_widget, array(
			'div' => array(
				'id' => array(),
				'class' => array(),
			),
			'span' => array(
				'id' => array(),
				'class' => array(),
			),
		));
		
		if($instance['max_width'] && is_numeric($instance['max_width'])) {
			$instance['max_width'].='px';
		}
	
		if($instance['form_id']) {
			$html='[contact-form-7 id="'.esc_attr($instance['form_id']).'"]';
			if($instance['max_width']) {
				$html='<div style="max-width:'.esc_attr($instance['max_width']).';margin:0 auto">'.$html.'</div>';
			}
			echo do_shortcode($html);
		}
		
		echo wp_kses($after_widget, array(
			'div' => array(
				'id' => array(),
				'class' => array(),
			),
			'span' => array(
				'id' => array(),
				'class' => array(),
			),
		));
	
	}


	/* Sanitize widget form values as they are saved. */
		
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		
		$instance['form_id'] = $new_instance['form_id'];
		$instance['max_width'] = $new_instance['max_width'];
	
		return $instance;
	}


	/* Back-end widget form. */
		 
	function form( $instance ) {
	
		$instance = wp_parse_args( (array) $instance, $this->instance_defaults );
		
		?>

		<!-- Widget Form: Select -->
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'form_id' ) ); ?>"><?php esc_html_e('Form:', 'wheelsberry') ?></label>
			<select id="<?php echo esc_attr( $this->get_field_id( 'form_id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'form_id' ) ); ?>">
			<?php
				$cf7forms=get_posts(array('post_type' => 'wpcf7_contact_form', 'posts_per_page' => -1));
				if($cf7forms){
					foreach($cf7forms as $cf7form){
						echo '<option value="'.esc_attr($cf7form->ID).'"'.($instance['form_id'] == $cf7form->ID ? ' selected="selected"' : '').'>'.esc_html($cf7form->post_title).'</option>';
					}
				}
			?>
			</select>
		</p>	

		<!-- Maximum width: Text Input -->
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'max_width' )); ?>"><?php esc_html_e('Maximum width of the form in pixels (optional):', 'wheelsberry') ?></label>
			<input class="widefat" type="text" id="<?php echo esc_attr( $this->get_field_id( 'max_width' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'max_width' ) ); ?>" value="<?php echo esc_attr( $instance['max_width'] ); ?>" />
		</p>			
		
		<?php
	}
}
?>