<?php
define('WHEELSBERRY_WPB_DIR', WHEELSBERRY_TEMPLATE_DIR . '/wpb'); // without the trailing slash
define('WHEELSBERRY_WPB_DIR_URI', WHEELSBERRY_TEMPLATE_DIR_URI . '/wpb' ); // without trailing slash

function wheelsberry_wpb_activated() {
	return defined( 'WPB_VC_VERSION' );
}

function wheelsberry_vc_set_as_theme() {
	vc_set_as_theme(true);
}
add_action( 'vc_before_init', 'wheelsberry_vc_set_as_theme' );

function wheelsberry_vc_backend_default() {
	update_option( 'wpb_js_gutenberg_disable', 1 );
}
add_action('after_switch_theme', 'wheelsberry_vc_backend_default');

function wheelsberry_vc_after_init() {
	if( ! vc_is_updater_disabled() ) {
		remove_filter( 'upgrader_pre_download', array( vc_updater(), 'preUpgradeFilter' ) );
		remove_action( 'wp_ajax_nopriv_vc_check_license_key', array( vc_updater(), 'checkLicenseKeyFromRemote' ) );
		
		remove_filter( 'pre_set_site_transient_update_plugins', array( vc_updater()->updateManager(), 'check_update' ) );
		remove_filter( 'plugins_api', array( vc_updater()->updateManager(), 'check_info' ) );
		remove_action( 'in_plugin_update_message-' . vc_plugin_name(), array( vc_updater()->updateManager(), 'addUpgradeMessageLink' ) );
	}
	
	if ( vc_user_access()
			->wpAny( 'manage_options' )
			->part( 'settings' )
			->can( 'vc-updater-tab' )
			->get()
	) {
		remove_action( 'admin_notices', array( vc_license(), 'adminNoticeLicenseActivation' ) );
	}
}
add_action( 'vc_after_init', 'wheelsberry_vc_after_init' );

function wheelsberry_wpb_disable_gutenberg($theme) {
	update_option( 'wpb_js_gutenberg_disable', '1' );
}
add_action('after_switch_theme', 'wheelsberry_wpb_disable_gutenberg');

/******************************************/

if( wheelsberry_wpb_activated() && get_option('wheelsberry_disable_wpb_addons') != 'true' ) {

	add_filter('use_block_editor_for_post', '__return_false');

	function wheelsberry_wpb_remove_grid() {
		if(defined('VC_PAGE_MAIN_SLUG') && class_exists('Vc_Grid_Item_Editor')) {
			remove_submenu_page(VC_PAGE_MAIN_SLUG, 'edit.php?post_type=' . rawurlencode( Vc_Grid_Item_Editor::postType() ));
			
			global $wp_post_types;
			if(isset($wp_post_types['vc_grid_item'])) {
				unset($wp_post_types['vc_grid_item']);
			}
		}
	}
	add_action('vc_menu_page_build', 'wheelsberry_wpb_remove_grid', 20);

	vc_set_shortcodes_templates_dir(WHEELSBERRY_WPB_DIR . '/vc_templates/');
		
	require_once (WHEELSBERRY_WPB_DIR . '/functions/attribute-types.php');
	require_once (WHEELSBERRY_WPB_DIR . '/functions/options.php');
	require_once (WHEELSBERRY_WPB_DIR . '/functions/misc.php');
	require_once (WHEELSBERRY_WPB_DIR . '/functions/custom-shortcodes.php');
	require_once (WHEELSBERRY_WPB_DIR . '/functions/modifications.php');

	/**
	 * Styles & Scripts
	 */
	
	omfw_Framework::body_add_class('om-wpb');
	
	function wheelsberry_wpb_admin_scripts() {
		if ( in_array( get_post_type(), vc_editor_post_types() )) {
			wp_enqueue_style( 'wheelsberry_wpb_admin_styles', WHEELSBERRY_WPB_DIR_URI . '/assets/css/wpb-admin.css', array(), WHEELSBERRY_THEME_VERSION );
			//wp_enqueue_script( 'wheelsberry_wpb_custom_views', WHEELSBERRY_WPB_DIR_URI . '/assets/js/custom-views.js', array('jquery'), WHEELSBERRY_THEME_VERSION, true);
		}
	}
	add_action( 'admin_enqueue_scripts', 'wheelsberry_wpb_admin_scripts' );
	
	function wheelsberry_wpb_front_scripts() {
		wp_register_script( 'wheelsberry_js_composer_front', WHEELSBERRY_WPB_DIR_URI . '/assets/js/addon_js_composer_front.js', array('jquery'), WHEELSBERRY_THEME_VERSION, true );
		
		// add dependency to make sure that wheelsberry_js_composer_front will be loaded always before wpb_composer_front_js
		if(isset($GLOBALS['wp_scripts']->registered['wpb_composer_front_js']))
			$GLOBALS['wp_scripts']->registered['wpb_composer_front_js']->deps[]='wheelsberry_js_composer_front';
	}
	add_action( 'wp_enqueue_scripts', 'wheelsberry_wpb_front_scripts' );
	
	
	
	function wheelsberry_wpb_head_styles() {
		if ( in_array( get_post_type(), vc_editor_post_types() )) {

			$css = '
				.vc_colored-dropdown .om-button-color,
				.vc_btn3.vc_btn3-color-om-button-color
				{background-color:'.get_option('wheelsberry_buttons_color').' !important;color:#fff !important}

				.vc_colored-dropdown .om-accent-color,
				.vc_btn3.vc_btn3-color-om-accent-color
				{background-color:'.get_option('wheelsberry_accent_color').' !important;color:#fff !important}
				
				.vc_colored-dropdown .om-accent-color2,
				.vc_btn3.vc_btn3-color-om-accent-color2
				{background-color:'.get_option('wheelsberry_accent_color2').' !important;color:#fff !important}
			';
			
			$css=preg_replace('/\s*([\{\},;])\s*/','$1',$css);
			$css=trim(str_replace(',{','{',$css));

			wp_add_inline_style('js_composer', $css);

		}
	}
	add_action('admin_print_scripts-post.php', 'wheelsberry_wpb_head_styles', 11);
	add_action('admin_print_scripts-post-new.php', 'wheelsberry_wpb_head_styles', 11);


	if(isset($_GET['vc_editable']) && $_GET['vc_editable'] == 'true') { //frontend editor activated
		add_filter('pre_option_' . 'wheelsberry_lazyload', '__return_empty_string');
	} 
	
	// remove welcome screen of VC
	remove_action( 'vc_activation_hook', 'vc_page_welcome_set_redirect' );
	remove_action( 'admin_init', 'vc_page_welcome_redirect' );

}